[asterisk-commits] rmudgett: trunk r387741 - /trunk/include/asterisk/astobj2.h

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Mon May 6 12:15:22 CDT 2013


Author: rmudgett
Date: Mon May  6 12:15:20 2013
New Revision: 387741

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=387741
Log:
Update ao2_destructor_fn doxygen.

Modified:
    trunk/include/asterisk/astobj2.h

Modified: trunk/include/asterisk/astobj2.h
URL: http://svnview.digium.com/svn/asterisk/trunk/include/asterisk/astobj2.h?view=diff&rev=387741&r1=387740&r2=387741
==============================================================================
--- trunk/include/asterisk/astobj2.h (original)
+++ trunk/include/asterisk/astobj2.h Mon May  6 12:15:20 2013
@@ -383,12 +383,19 @@
 
 
 
-/*! \brief
- * Typedef for an object destructor. This is called just before freeing
- * the memory for the object. It is passed a pointer to the user-defined
- * data of the object.
- */
-typedef void (*ao2_destructor_fn)(void *);
+/*!
+ * \brief Typedef for an object destructor.
+ *
+ * \param vdoomed Object to destroy.
+ *
+ * \details
+ * This is called just before freeing the memory for the object.
+ * It is passed a pointer to the user-defined data of the
+ * object.
+ *
+ * \return Nothing
+ */
+typedef void (*ao2_destructor_fn)(void *vdoomed);
 
 /*! \brief Options available when allocating an ao2 object. */
 enum ao2_alloc_opts {




More information about the asterisk-commits mailing list